@@ -7,7 +7,7 @@ use Carp 'croak';
 # use Debug::ShowStuff::ShowVar;
 
 # version
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 #------------------------------------------------------------------------------
@@ -49,13 +49,15 @@ a different point in time.  EzDate2 has many features, here are a few:
 #------------------------------------------------------------------------------
 
 
-
 # warn levels
 use constant WARN_NONE   => 0;
 use constant WARN_STDERR => 1;
 use constant WARN_CROAK  => 2;
 our $default_warning = WARN_STDERR;
 
+# default time zone
+our $default_time_zone = undef;
+
 
 #------------------------------------------------------------------------------
 # object overloading
@@ -330,7 +332,9 @@ sub TIEHASH {
 	else {
 		# set DateTime object to current time
 		$eztied->{'dt'} = DateTime->now(
-			time_zone  => DateTime::TimeZone->new( name => 'local' )->name(),
+			time_zone =>
+				$Date::EzDate::default_time_zone ||
+				DateTime::TimeZone->new( name => 'local' )->name(),
 		);
 		
 		# if time is a scalar and has content, call timefromstring()
@@ -1883,6 +1887,10 @@ Version: 0.01
 
 Initial release.
 
+=item Version 0.02 July 23, 2016
+
+Added support for default time zone.
+
 =back
 
 =cut
@@ -1894,6 +1902,8 @@ Initial release.
 
 #------------------------------------------------------------------------------
 # module info
+# This info is used by a home-grown CPAN module builder. This info has no use
+# in the wild.
 #
 {
 	# include in CPAN distribution
